Package: UsingR
Version: 2.0-8
Title: Data Sets, Etc. for the Text "Using R for Introductory
        Statistics", Second Edition
Authors@R: person(given = "John",
                    family = "Verzani",
                    role = c("aut","cre"),
                    email = "verzani@math.csi.cuny.edu")
Maintainer: John Verzani <verzani@math.csi.cuny.edu>
Description: A collection of data sets to accompany the
    textbook "Using R for Introductory Statistics," second
    edition.
Depends: R (>= 2.15.0), MASS, HistData, Hmisc
Suggests: zoo, ggplot2, vcd, lubridate, aplpack
License: GPL (>= 2)
LazyData: TRUE
NeedsCompilation: no
Packaged: 2026-02-12 21:25:02 UTC; jverzani
Author: John Verzani [aut, cre]
Repository: CRAN
Date/Publication: 2026-02-13 09:50:07 UTC
Built: R 4.6.0; ; 2026-04-30 05:42:27 UTC; unix
