# Generated by roxygen2 (4.1.1): do not edit by hand

S3method(DOTplot,default)
S3method(DOTplot,formula)
S3method(DensityPlot,default)
S3method(DensityPlot,formula)
S3method(confint,htest)
S3method(simple.densityplot,default)
S3method(simple.densityplot,formula)
S3method(simple.violinplot,default)
S3method(simple.violinplot,formula)
S3method(violinplot,default)
S3method(violinplot,formula)
export(DOTplot)
export(DensityPlot)
export(QQplot)
export(Split.zoo)
export(answers)
export(errata)
export(getAnswer)
export(headtail)
export(lorem)
export(scatter.with.hist)
export(simple.chutes)
export(simple.densityplot)
export(simple.eda)
export(simple.eda.ts)
export(simple.fancy.stripchart)
export(simple.freqpoly)
export(simple.hist.and.boxplot)
export(simple.lag)
export(simple.lm)
export(simple.median.test)
export(simple.scatterplot)
export(simple.sim)
export(simple.violinplot)
export(simple.z.test)
export(squareplot)
export(superbarplot)
export(violinplot)
import(HistData)
import(Hmisc)
import(MASS)
importFrom(grDevices,gray)
importFrom(grDevices,nclass.scott)
importFrom(grDevices,rainbow)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,boxplot)
importFrom(graphics,curve)
importFrom(graphics,hist)
importFrom(graphics,layout)
importFrom(graphics,layout.show)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,locator)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,plot.new)
importFrom(graphics,plot.window)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rug)
importFrom(graphics,stripchart)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(stats,acf)
importFrom(stats,density)
importFrom(stats,fitted.values)
importFrom(stats,lm)
importFrom(stats,lowess)
importFrom(stats,na.omit)
importFrom(stats,pbinom)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,qqline)
importFrom(stats,qqnorm)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,supsmu)
importFrom(stats,ts)
importFrom(utils,URLdecode)
importFrom(utils,browseURL)
importFrom(utils,capture.output)
importFrom(utils,count.fields)
importFrom(utils,download.file)
importFrom(utils,read.table)
